@@ -285,21 +285,29 @@ class TrackedFile(TrackedFile, PublishOKItem):
         kitsu_bindings = self.root().project().kitsu_bindings()
         settings = get_contextual_dict(self, 'settings')
         file_category = settings['file_category']
-        casting = dict()
+        casting = {}
 
         if file_category == 'PROD':
-            shot = settings['shot']
-            sequence = settings['sequence']
-            film = settings['film']
-            casting = kitsu_bindings.get_shot_casting(shot, sequence)
-            entity_oid = self.root().project().oid()
-            entity_oid += f"/films/{film}/sequences/{sequence}/shots/{shot}"
+            film = settings.get('film', None)
+            sequence = settings.get('sequence', None)
+
+            if film is not None and sequence is not None:
+                entity_oid = self.root().project().oid()
+                entity_oid += f'/films/{film}/sequences/{sequence}'
+
+                shot = settings.get('shot', None)
+
+                if shot is not None:
+                    entity_oid += f'/shots/{shot}'
+                    casting = kitsu_bindings.get_shot_casting(shot, sequence)
         elif file_category == 'LIB':
-            asset_name = settings['asset_name']
-            asset_family = settings['asset_family']
-            asset_type = settings['asset_type']
-            entity_oid = self.root().project().oid()
-            entity_oid += f"/asset_lib/asset_types/{asset_type}/asset_families/{asset_family}/assets/{asset_name}"
+            asset_name = settings.get('asset_name', None)
+            asset_family = settings.get('asset_family', None)
+            asset_type = settings.get('asset_type', None)
+
+            if all(i is not None for i in [asset_name, asset_family, asset_type]):
+                entity_oid = self.root().project().oid()
+                entity_oid += f'/asset_lib/asset_types/{asset_type}/asset_families/{asset_family}/assets/{asset_name}'
 
         dependency_template = settings.get('dependency_template', self.name())
 
@@ -362,6 +370,38 @@ class FileSystemMap(BaseFileSystemMap):
     create_file_action   = flow.Child(CreateFileAction).ui(label='Create file')
     create_folder_action = flow.Child(CreateFolderAction).ui(label='Create folder')
 
+    def add_file(self, name, extension, display_name=None, base_name=None, tracked=False, default_path_format=None):
+        if base_name is None:
+            prefix = self.default_file_prefix.get()
+            base_name = prefix + name
+        if display_name is None:
+            display_name = f'{name}.{extension}'
+        
+        f = super(FileSystemMap, self).add_file(
+            name, extension,
+            display_name,
+            base_name,
+            tracked,
+            default_path_format
+        )
+        return f
+
+    def add_folder(self, name, display_name=None, base_name=None, tracked=False, default_path_format=None):
+        if base_name is None:
+            prefix = self.default_file_prefix.get()
+            base_name = prefix + name
+        if display_name is None:
+            display_name = name
+        
+        f = super(FileSystemMap, self).add_folder(
+            name,
+            display_name,
+            base_name,
+            tracked,
+            default_path_format
+        )
+        return f
+
     def get_parent_path(self):
         return get_context_value(
             self._parent, 'file_path', delim='/'
