@@ -1,3 +1,5 @@
+import datetime
+import timeago
 from kabaret import flow
 from libreflow.baseflow.users import User as BaseUser
 
@@ -6,7 +8,7 @@ class User(BaseUser):
 
     last_visit = flow.Computed()
     libreflow_version = flow.Computed().ui(label="libreflow") 
-    project_version = flow.Computed().ui(label="libreflow.tinykin") 
+    project_version = flow.Computed().ui(label="libreflow.flows") 
     _last_visit = flow.IntParam(0)
     _last_libreflow_used_version = flow.Param(None)
     _last_project_used_version = flow.Param(None)
@@ -34,7 +36,7 @@ class User(BaseUser):
                     child_value.set("%s" % str(user_current_version))
         elif child_value is self.project_version:
             from packaging import version
-            requiered_version = version.parse(self.root().project().admin.project_settings.libreflow_siren_version.get())
+            requiered_version = version.parse(self.root().project().admin.project_settings.project_version.get())
             user_current_version = self._last_project_used_version.get()
             if not user_current_version:
                 child_value.set("Unknown")
